@@ -1,7 +1,7 @@
-from worker.app.modules.__init__ import Module
+from worker.app.modules.activity_module import ActivityModule
 
 
-class ConnectionModule(Module):
+class ConnectionModule(ActivityModule):
     """
     This is an abstract module that needs to be extended by actual modules.
     An example of this module would be running an app after a connection occur.
