@@ -14,6 +14,18 @@ class EventTypes(Enum):
     GENERIC = "generic_event"
 
 
+class ChannelStatus(Enum):
+    ON = "on"
+    OFF = "off"
+    MISSING = "missing"
+
+
+class DataStatus(Enum):
+    VALID = "valid"
+    MISSING = "missing"
+    OVERRIDDEN = "overridden"
+
+
 class Environment(Enum):
     QA = "qa"
     STAGING = "staging"
